@@ -2,7 +2,7 @@ from livestreamer.compat import unquote
 from livestreamer.stream import RTMPStream
 from livestreamer.plugin import Plugin
 from livestreamer.exceptions import PluginError, NoStreamsError
-from livestreamer.utils import urlget
+from livestreamer.utils import urlget, res_json
 
 import re
 
@@ -19,19 +19,25 @@ class ILive(Plugin):
         if not match:
             raise NoStreamsError(self.url)
 
-        rtmp = match.group(2)
-        playpath = match.group(3)
-        swfurl = match.group(1)
+        params = {
+            "rtmp": match.group(2),
+            "pageUrl": self.url,
+            "swfVfy": match.group(1),
+            "playpath" : match.group(3),
+            "live": True
+        }
 
+        match = re.search("(http(s)?://.+/server/server.php\?id=\d+)",
+                          res.text)
+        if match:
+            token_url = match.group(1)
+            res = res_json(urlget(token_url, headers=dict(Referer=self.url)))
+            token = res.get("token")
+            if token:
+                params["token"] = token
 
         streams = {}
-        streams["live"] = RTMPStream(self.session, {
-            "rtmp": rtmp,
-            "pageUrl": self.url,
-            "swfVfy": swfurl,
-            "playpath" : playpath,
-            "live": True
-        }, redirect=True)
+        streams["live"] = RTMPStream(self.session, params, redirect=True)
 
         return streams
 
